PyTorch Yard - PyTorch experiment runner
========================================

Work in progress.

Requires manual installation of hydra-torch configs:

- hydra-configs-torch @ git+https://github.com/pytorch/hydra-torch/#subdirectory=hydra-configs-torch
- hydra-configs-torchvision @ git+https://github.com/pytorch/hydra-torch/#subdirectory=hydra-configs-torchvision

::

    pip install git+https://github.com/pytorch/hydra-torch/#subdirectory=hydra-configs-torch git+https://github.com/pytorch/hydra-torch/#subdirectory=hydra-configs-torchvision
